@@ -4,10 +4,20 @@ pub mod alert_bulk_response;
 pub use self::alert_bulk_response::AlertBulkResponse;
 pub mod alert_event_type_enum;
 pub use self::alert_event_type_enum::AlertEventTypeEnum;
-pub mod alert_method_enum;
-pub use self::alert_method_enum::AlertMethodEnum;
 pub mod alert_request;
 pub use self::alert_request::AlertRequest;
+pub mod ansible_facts;
+pub use self::ansible_facts::AnsibleFacts;
+pub mod ansible_facts_request;
+pub use self::ansible_facts_request::AnsibleFactsRequest;
+pub mod appliance;
+pub use self::appliance::Appliance;
+pub mod appliance_pki;
+pub use self::appliance_pki::AppliancePki;
+pub mod appliance_pki_request;
+pub use self::appliance_pki_request::AppliancePkiRequest;
+pub mod appliance_request;
+pub use self::appliance_request::ApplianceRequest;
 pub mod artifact_types_enum;
 pub use self::artifact_types_enum::ArtifactTypesEnum;
 pub mod callback_token_auth_request;
@@ -16,30 +26,20 @@ pub mod callback_token_verification;
 pub use self::callback_token_verification::CallbackTokenVerification;
 pub mod callback_token_verification_request;
 pub use self::callback_token_verification_request::CallbackTokenVerificationRequest;
-pub mod camera_controller;
-pub use self::camera_controller::CameraController;
-pub mod camera_controller_request;
-pub use self::camera_controller_request::CameraControllerRequest;
-pub mod camera_source_type_enum;
-pub use self::camera_source_type_enum::CameraSourceTypeEnum;
-pub mod camera_type_enum;
-pub use self::camera_type_enum::CameraTypeEnum;
 pub mod command_enum;
 pub use self::command_enum::CommandEnum;
+pub mod create_ansible_facts_request;
+pub use self::create_ansible_facts_request::CreateAnsibleFactsRequest;
+pub mod create_appliance_pki_request;
+pub use self::create_appliance_pki_request::CreateAppliancePkiRequest;
+pub mod create_appliance_request;
+pub use self::create_appliance_request::CreateApplianceRequest;
 pub mod detail_response;
 pub use self::detail_response::DetailResponse;
-pub mod device;
-pub use self::device::Device;
 pub mod device_calibration;
 pub use self::device_calibration::DeviceCalibration;
 pub mod device_calibration_request;
 pub use self::device_calibration_request::DeviceCalibrationRequest;
-pub mod device_identity;
-pub use self::device_identity::DeviceIdentity;
-pub mod device_identity_ca_certs;
-pub use self::device_identity_ca_certs::DeviceIdentityCaCerts;
-pub mod device_request;
-pub use self::device_request::DeviceRequest;
 pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod event_source_enum;
@@ -58,8 +58,6 @@ pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
 pub use self::model_artifact::ModelArtifact;
-pub mod nested;
-pub use self::nested::Nested;
 pub mod octo_print_device;
 pub use self::octo_print_device::OctoPrintDevice;
 pub mod octo_print_device_key;
@@ -118,12 +116,10 @@ pub mod octoprint_python_request;
 pub use self::octoprint_python_request::OctoprintPythonRequest;
 pub mod paginated_alert_list;
 pub use self::paginated_alert_list::PaginatedAlertList;
-pub mod paginated_camera_controller_list;
-pub use self::paginated_camera_controller_list::PaginatedCameraControllerList;
+pub mod paginated_appliance_list;
+pub use self::paginated_appliance_list::PaginatedApplianceList;
 pub mod paginated_device_calibration_list;
 pub use self::paginated_device_calibration_list::PaginatedDeviceCalibrationList;
-pub mod paginated_device_list;
-pub use self::paginated_device_list::PaginatedDeviceList;
 pub mod paginated_experiment_device_config_list;
 pub use self::paginated_experiment_device_config_list::PaginatedExperimentDeviceConfigList;
 pub mod paginated_experiment_list;
@@ -160,12 +156,10 @@ pub mod patched_alert_bulk_request_request;
 pub use self::patched_alert_bulk_request_request::PatchedAlertBulkRequestRequest;
 pub mod patched_alert_request;
 pub use self::patched_alert_request::PatchedAlertRequest;
-pub mod patched_camera_controller_request;
-pub use self::patched_camera_controller_request::PatchedCameraControllerRequest;
+pub mod patched_appliance_request;
+pub use self::patched_appliance_request::PatchedApplianceRequest;
 pub mod patched_device_calibration_request;
 pub use self::patched_device_calibration_request::PatchedDeviceCalibrationRequest;
-pub mod patched_device_request;
-pub use self::patched_device_request::PatchedDeviceRequest;
 pub mod patched_octo_print_device_request;
 pub use self::patched_octo_print_device_request::PatchedOctoPrintDeviceRequest;
 pub mod patched_print_session_request;
@@ -202,6 +196,8 @@ pub mod printer_profile_request;
 pub use self::printer_profile_request::PrinterProfileRequest;
 pub mod printer_state_enum;
 pub use self::printer_state_enum::PrinterStateEnum;
+pub mod release_channel_enum;
+pub use self::release_channel_enum::ReleaseChannelEnum;
 pub mod remote_command_event;
 pub use self::remote_command_event::RemoteCommandEvent;
 pub mod remote_command_event_event_type_enum;
